==> haskell-unicode-transforms-0.2.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unicode-transforms.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unicode-transforms
version: 0.2.1
id: unicode-transforms-0.2.1-8q7tL2skgYi8hmY9m3wNwt
key: unicode-transforms-0.2.1-8q7tL2skgYi8hmY9m3wNwt
license: BSD3
copyright: 2016 Harendra Kumar,
           2014–2015 Antonio Nikishaev
maintainer: harendra.kumar@gmail.com
stability: Experimental
homepage: http://github.com/harendra-kumar/unicode-transforms
synopsis: Unicode normalization
description:
    Fast Unicode 8.0 normalization in Haskell (NFC, NFKC, NFD, NFKD).
category: Data,Text,Unicode
author: Harendra Kumar
exposed: True
exposed-modules:
    Data.ByteString.UTF8.Normalize Data.Text.Normalize
    Data.Unicode.Types
hidden-modules: Data.Unicode.Internal.NormalizeStream
                Data.Unicode.Properties.BitArray
                Data.Unicode.Properties.CombiningClass
                Data.Unicode.Properties.Compositions
                Data.Unicode.Properties.Decomposable
                Data.Unicode.Properties.DecomposableK
                Data.Unicode.Properties.Decompose
                Data.Unicode.Properties.DecomposeHangul
                Data.Unicode.Properties.Decompositions
                Data.Unicode.Properties.DecompositionsK
                Data.Unicode.Properties.DecompositionsK2
abi: 6a65561c5cb6c17e2867b5fdb089e21d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/unicode-transforms-0.2.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/unicode-transforms-0.2.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/unicode-transforms-0.2.1
hs-libraries: HSunicode-transforms-0.2.1-8q7tL2skgYi8hmY9m3wNwt
depends:
    base-4.9.0.0 bitarray-0.0.1.1-9oSzik18SiaLBtzGdFPDHQ
    bytestring-0.10.8.1 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-unicode-transforms/html/unicode-transforms.haddock
haddock-html: /usr/share/doc/haskell-unicode-transforms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unicode-transforms-0.2.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unicode-transforms.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unicode-transforms
version: 0.2.1
id: unicode-transforms-0.2.1-EeeQ6pTxIlHKoXYgUimGP0
key: unicode-transforms-0.2.1-EeeQ6pTxIlHKoXYgUimGP0
license: BSD3
copyright: 2016 Harendra Kumar,
           2014–2015 Antonio Nikishaev
maintainer: harendra.kumar@gmail.com
stability: Experimental
homepage: http://github.com/harendra-kumar/unicode-transforms
synopsis: Unicode normalization
description:
    Fast Unicode 8.0 normalization in Haskell (NFC, NFKC, NFD, NFKD).
category: Data,Text,Unicode
author: Harendra Kumar
exposed: True
exposed-modules:
    Data.ByteString.UTF8.Normalize Data.Text.Normalize
    Data.Unicode.Types
hidden-modules: Data.Unicode.Internal.NormalizeStream
                Data.Unicode.Properties.BitArray
                Data.Unicode.Properties.CombiningClass
                Data.Unicode.Properties.Compositions
                Data.Unicode.Properties.Decomposable
                Data.Unicode.Properties.DecomposableK
                Data.Unicode.Properties.Decompose
                Data.Unicode.Properties.DecomposeHangul
                Data.Unicode.Properties.Decompositions
                Data.Unicode.Properties.DecompositionsK
                Data.Unicode.Properties.DecompositionsK2
abi: ac82f4bc76f5f61eda993a155577bade
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/unicode-transforms-0.2.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/unicode-transforms-0.2.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/unicode-transforms-0.2.1
hs-libraries: HSunicode-transforms-0.2.1-EeeQ6pTxIlHKoXYgUimGP0
depends:
    base-4.9.0.0 bitarray-0.0.1.1-9oSzik18SiaLBtzGdFPDHQ
    bytestring-0.10.8.1 text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
haddock-interfaces: /usr/share/doc/haskell-unicode-transforms/html/unicode-transforms.haddock
haddock-html: /usr/share/doc/haskell-unicode-transforms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
